API docs for “spamfighter.plugins.test.test_static_doman_provider.StaticDefaultDomainProviderTestCase”

# Class s.p.t.t.StaticDefaultDomainProviderTestCase(unittest.TestCase):

Part of spamfighter.plugins.test.test_static_doman_provider View Source View In Hierarchy

Тест на `spamfighter.plugins.static_domain_provider.StaticDefaultDomainProvider`.

Method | testInterface | Undocumented
Method | testEmptyDomain | Undocumented

def testInterface(self): (source)
Undocumented
def testEmptyDomain(self): (source)
Undocumented